@@ -1,6 +1,6 @@
 from abc import abstractmethod, ABC
 
-from investing_algorithm_framework.core.models import Order
+from investing_algorithm_framework.core.models import Order, OrderStatus
 from investing_algorithm_framework.core.identifier import Identifier
 
 
@@ -11,18 +11,18 @@ class OrderExecutor(ABC, Identifier):
 
     @abstractmethod
     def execute_limit_order(
-            self, order: Order, algorithm_context, **kwargs
+        self, order: Order, algorithm_context, **kwargs
     ) -> bool:
         raise NotImplementedError()
 
     @abstractmethod
     def execute_market_order(
-            self, order: Order, algorithm_context, **kwargs
+        self, order: Order, algorithm_context, **kwargs
     ) -> bool:
         raise NotImplementedError()
 
     @abstractmethod
-    def update_order_status(
-            self, order: Order, algorithm_context, **kwargs
-    ) -> bool:
+    def get_order_status(
+        self, order: Order, algorithm_context, **kwargs
+    ) -> OrderStatus:
         raise NotImplementedError()
